Models
======

* `trVAE`_
* `scVI`_
* `scANVI`_
* `TotalVI`_

trVAE
-----

.. autoclass:: scarches.models.TRVAE
    :members:
    :undoc-members:
    :show-inheritance:

scVI
----

.. autoclass:: scarches.models.SCVI
    :members:
    :undoc-members:
    :show-inheritance:

scANVI
--------

.. autoclass:: scarches.models.SCANVI
    :members:
    :undoc-members:
    :show-inheritance:

TotalVI
--------

.. autoclass:: scarches.models.TOTALVI
    :members:
    :undoc-members:
    :show-inheritance:
